{% extends 'base.html' %}

{% load widget_tweaks %}
{% load url_link %}

{% load crispy_forms_tags %}

{% block content %}

<h4 class="display-titre" style="background-color: rgb(255, 255, 255)">Add User for {{ project.name }}</h4>

<form method="post">
    {% csrf_token %}
    {% crispy form %}
</form>

</br>


<button type="button" class="btn btn-secondary"><a href="{% url 'core:mapping_project_user' project.id %}"> Back
    </a></button>

{% endblock %}