{% extends 'base.html' %}

{% load widget_tweaks %}

{% block content %}

<h4 class="display-titre" style="background-color: rgb(255, 255, 255)">Delete a {{data_type}} Mapping</h4>




<form method="POST">{% csrf_token %}
    Do you want to delete the mapping of the {{data_type}} <strong class="strong">"{{ obj.name }}"</strong> from
    OpenLink ?
    <div class='inline-block'></br>
        <div class="top_title">
            <input type="submit" class="btn btn-danger" value="Yes">
</form>
</div>
<button type="button" class="btn btn-secondary">
    {% if data_type == "project"%}
    <a href="{% url 'core:edit-project'  project_id %}">Cancel</a></button>
    {% elif data_type == "investigation"%}
    <a href="{% url 'core:edit-investigation' project_id type_id %}">Cancel</a></button>
    {% elif  data_type == "study" %}
    <a href="{% url 'core:edit-study' project_id investigation_id type_id %}">Cancel</a></button>
    {% elif  data_type == "assay" %}
    <a href="{% url 'core:edit-assay' project_id investigation_id type_id %}">Cancel</a></button>
    {% elif  data_type == "dataset" %}
    <a href="{% url 'core:edit-dataset' project_id investigation_id type_id %}">Cancel</a></button>
    {% endif %}
</div>

{% endblock %}