{% extends "base.html" %}
{% load static i18n %}
{% block content %}

<div class="container">
    <h3>OpenLink Project</h3>
    <p>The web application we want to develop would make it possible to establish a logical link between the various
        media used by the research teams.
        To us, it seems to be a primary need to assist the researchers with the monitoring and the enrichment of the
        metadata throughout the data lifecycle.
        </br>In parallel, the development of a methodology in the monitoring of projects will aim to support the
        research teams to show
        them the added value of developing a data management plan from the beginning of a project, raise awareness of
        data storage management costs and train them in the FAIR principles.
    </p>
    <p>
        <b>OpenLink will be able to easily interface with any type of data management tools such as:</b>
    </p>
    <ul>
        <p class="openlink_img">
            <img src="{% static 'images/workflow-openlink.png' %}" alt="OpenLink" height="250">
        </p>

    </ul>



    {% endblock %}


</div>

</body>