{% extends "base.html" %}
{% load static i18n %}
{% load param %}
{% block content %}

<h4 style="background-color: rgb(255, 255, 255)">OpenLink</h4>


<div class="container">
    <h5></h5><i class="fa fa-user"></i> User Profile</h5>
    <ul>
        <li><b>Username:</b> {{ user.username }}</li>
        <li><b>email:</b> {{ user.email }}</li>
        <li><b>First name:</b> {{ user.first_name }}</li>
        <li><b>Last name:</b> {{ user.last_name }} </li>
        <li><b>Your team:</b> {% for team in user.profile.team.all %}
            {{ team }}
            {% endfor %} </li>
        <li><b>Added Tools:</b>
            {% for tool in tool_list %}
        <li><b>Tool {{ forloop.counter }}:</b> {{ tool.name }} {{tool|param:"url"}}</li>
        {% endfor %}
    </ul>
</div>
</body>



{% endblock %}