{% extends "base.html" %}
{% load static i18n %}
{% load param %}
{% block content %}

<h4 style="background-color: rgb(255, 255, 255)">OpenLink</h4>


<div class="container">
    <h5></h5><i class="fa fa-envelope-open"></i> Contact </h5>
    <br>
    <span>Please contact us <a href="">here</a> if you encounter any issue</span>
</div>
</body>



{% endblock %}