{% load static %}
{% load guardian_tags %}
<!DOCTYPE html>
<html lang="en">
<head>
    {% comment %} html header {% endcomment %}
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">

    <title>
        {% block title %}
            OpenLink
        {% endblock %}
    </title>

    <meta http-equiv="content-type" content="text/html; charset=utf-8" />

    <meta name="description" content=" content=" {% block meta-description %} OpenLink will establish specialized
            gateways between the various data management tools throughout the data lifecycle by exploiting their respective
        APIs, while providing a cross-cutting view of their data to the research teams. " {% endblock %}" />
    <link rel="shortcut icon" type="image/png" href="{% static "images/favicon.ico" %}" />

    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.0/css/bootstrap.min.css">
    {% comment %} Our Custom CSS {% endcomment %}
    <link rel="stylesheet" href="{% static 'css/style.css' %}">

        <link rel="stylesheet" href="{% static 'css/openlink.css' %}">
        <link rel="stylesheet" href="{% static 'css/generique.css' %}">
        <link rel="stylesheet" href="{% static 'css/bootstrap-tagsinput.css' %}">
        {% block custom_css %}
            <link rel="stylesheet" type="text/css" href="https://cdn.datatables.net/1.10.19/css/dataTables.bootstrap.min.css">
            <link rel="stylesheet" type="text/css" href="https://cdn.datatables.net/1.10.19/css/jquery.dataTables.css">
            <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/jstree/3.2.1/themes/default/style.min.css" />
        
        
        
        
        {% endblock %}
    
        {% comment %} js imports {% endcomment %}
        {% comment %} jQuery CDN - Slim version (=without AJAX) {% endcomment %}
        <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
        {% comment %} Popper.JS {% endcomment %}
        <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.0/umd/popper.min.js"
            integrity="sha384-cs/chFZiN24E4KMATLdqdvsezGxaGsi4hLGOzlXwp5UZB1LY//20VyM2taTB4QvJ" crossorigin="anonymous">
        </script>
        {% comment %} Bootstrap JS {% endcomment %}
        {% comment %} <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.1.0/js/bootstrap.min.js"
                integrity="sha384-uefMccjFJAIv6A+rW+L4AHf99KvxDjWSu1z9VI8SKNVmz4sk7buKt/6v9KI65qnm" crossorigin="anonymous">
        </script> {% endcomment %}
    
        {% comment %} Font Awesome JS {% endcomment %}
        <script defer src="https://use.fontawesome.com/releases/v5.0.13/js/solid.js"
            integrity="sha384-tzzSw1/Vo+0N5UhStP3bvwWPq+uvzCMfrN1fEFe+xBmv1C/AtVX5K0uZtmcHitFZ" crossorigin="anonymous">
        </script>
        <script defer src="https://use.fontawesome.com/releases/v5.0.13/js/fontawesome.js"
            integrity="sha384-6OIrr52G08NpOFSZdxxz1xdNSndlD4vdcf/q2myIUVO0VsqaGHJsB0RaBE01VTOY" crossorigin="anonymous">
        </script>
    
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.0/js/bootstrap.min.js"
        integrity="sha384-OgVRvuATP1z7JjHLkuOU7Xw704+h835Lr+6QL9UvYjZE3Ipu6Tp75j7Bh/kR0JKI" crossorigin="anonymous">
    </script>
    <script src="{% static 'js/mdb.min.js' %}"></script>
    <script src="{% static 'js/fontawesome.min.js' %}"></script>
    <script src="{% static 'js/modules/treeview.min.js' %}"></script>
    <script src="{% static 'js/modules/animations-extended.min.js' %}"></script>
    <script src="{% static 'js/bootstrap-tagsinput.min.js' %}"></script>

    <script src="https://cdn.jsdelivr.net/npm/darkmode-js@1.5.5/lib/darkmode-js.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/js-cookie@rc/dist/js.cookie.min.js"></script>

    <script src="https://cdnjs.cloudflare.com/ajax/libs/jstree/3.3.11/jstree.min.js"></script>

</head>
<body>
    {% include 'nav.html' %}


    {% for message in messages %}
        <div class="alert alert-{{ message.tags }} mb-0 alert-dismissible fade show" role="alert">
            {{ message }}
            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                <span aria-hidden="true">&times;</span>
            </button>
        </div>
    {% endfor %}
    <div class="container">
        {% block content %}{% endblock %}
    </div>

    <script type="text/javascript" charset="utf8" src="https://cdn.datatables.net/1.10.19/js/jquery.dataTables.js">
    </script>
    <script>
        $(document).ready(function () {
            $('#table.table').DataTable({
                searching: true,
                info: false
            });
        });
    </script>
    <script>
        $(document).ready(function () {
            $('[data-toggle="popover"]').popover();
        });
    </script>
    <script>
        $(document).ready(function () {

            $('#sidebarCollapse').on('click', function () {
                $('#sidebar').toggleClass('active');
            });

        });
    </script>
    {% comment %} <footer>
        {%if debug %}
            {{ request.get_full_path }}
            <br>
            {{request.resolver_match.view_name}}
            <br>
            {{request.resolver_match.url_name}}
            <br>
            {{request.resolver_match}}
            <br>
            {{request.resolver_match.func}}
            <br>
            {{request.resolver_match.route}}
            <br>
        {%endif%}
    </footer> {% endcomment %}
</body>

</html>