{% extends 'base.html' %}

{% load widget_tweaks %}

{% block content %}

<h4 class="display-titre" style="background-color: rgb(255, 255, 255)">Delete User from project {{project}}</h4>




<form action="delete_user_mapping/{{obj_str}}" method="POST">{% csrf_token %}
    Do you want to delete the user(s)
    {% for obj in users %}
    <strong class="strong">"{{ obj }} "</strong>
    {% endfor %}
    from the project <strong class="strong">"{{project}}"</strong> ?

    <br>
    All the mappings added by this user(s) will be deleted from {{project}}.
    </br>
    </br>
    <div class=row style="display: flex;" ;>
        <input type="hidden" name="users_list" value="{{obj_str}}">

        </br>
        <button type="button" class="btn btn-secondary"><a
                href='{% url 'core:mapping_project_user' project_id %}'>Cancel</a></button>
        &nbsp;<input type="submit" class="btn btn-danger" value="Delete">

</form>
</div>

{% endblock %}